AudioInfo class final

Metadata about an audio file or audio data.

Returned by AudioDecoder.getAudioInfo and AudioDecoder.getAudioInfoBytes.

Constructors

AudioInfo({required Duration duration, required int sampleRate, required int channels, required int bitRate, required String format})
Creates an AudioInfo with the given metadata.
const

Properties

bitRate int
Bit rate in bits per second (e.g., 128000 for 128 kbps).
final
channels int
Number of audio channels (1 = mono, 2 = stereo).
final
duration Duration
Total duration of the audio.
final
format String
Audio format identifier (e.g., 'mp3', 'm4a', 'wav').
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
Sample rate in Hz (e.g., 44100, 48000).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited