MethodChannelAudioDecoder class final
Platform implementation of audio_decoder that uses a method channel to communicate with native platform code.
- Inheritance
-
- Object
- PlatformInterface
- AudioDecoderPlatform
- MethodChannelAudioDecoder
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
convertToM4a(
String inputPath, String outputPath) → Future< String> -
override
-
convertToM4aBytes(
Uint8List inputData, String formatHint) → Future< Uint8List> -
override
-
convertToWav(
String inputPath, String outputPath, {int? sampleRate, int? channels, int? bitDepth}) → Future< String> -
override
-
convertToWavBytes(
Uint8List inputData, String formatHint, {int? sampleRate, int? channels, int? bitDepth, bool? includeHeader}) → Future< Uint8List> -
override
-
getAudioInfo(
String path) → Future< AudioInfo> -
override
-
getAudioInfoBytes(
Uint8List inputData, String formatHint) → Future< AudioInfo> -
override
-
getWaveform(
String path, int numberOfSamples) → Future< List< double> > -
override
-
getWaveformBytes(
Uint8List inputData, String formatHint, int numberOfSamples) → Future< List< double> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trimAudio(
String inputPath, String outputPath, Duration start, Duration end) → Future< String> -
override
-
trimAudioBytes(
Uint8List inputData, String formatHint, Duration start, Duration end, {String outputFormat = 'wav'}) → Future< Uint8List> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited