The interface that platform-specific implementations of audio_decoder must extend.
The base modifier ensures platform implementations extend this class
rather than implement it, so new methods can be added without breaking
existing implementations.
- Inheritance
-
- Object
- PlatformInterface
- AudioDecoderPlatform
- Implementers
Constructors
- AudioDecoderPlatform()
- Constructs an AudioDecoderPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
convertToM4a(
String inputPath, String outputPath) → Future< String> -
convertToM4aBytes(
Uint8List inputData, String formatHint) → Future< Uint8List> -
convertToWav(
String inputPath, String outputPath, {int? sampleRate, int? channels, int? bitDepth}) → Future< String> -
convertToWavBytes(
Uint8List inputData, String formatHint, {int? sampleRate, int? channels, int? bitDepth, bool? includeHeader}) → Future< Uint8List> -
getAudioInfo(
String path) → Future< AudioInfo> -
getAudioInfoBytes(
Uint8List inputData, String formatHint) → Future< AudioInfo> -
getWaveform(
String path, int numberOfSamples) → Future< List< double> > -
getWaveformBytes(
Uint8List inputData, String formatHint, int numberOfSamples) → Future< List< double> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trimAudio(
String inputPath, String outputPath, Duration start, Duration end) → Future< String> -
trimAudioBytes(
Uint8List inputData, String formatHint, Duration start, Duration end, {String outputFormat = 'wav'}) → Future< Uint8List>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AudioDecoderPlatform
-
The current platform-specific implementation.
getter/setter pair